@@ -8,8 +8,6 @@ import shutil
 import subprocess
 import sys
 import tempfile
-from collections import defaultdict
-from itertools import chain
 from pathlib import Path
 from textwrap import dedent
 from typing import Dict, Iterator, List, Optional, Set, Tuple
@@ -22,16 +20,8 @@ from nbqa import (
     save_source,
 )
 
-CONFIG_FILES: Dict[str, List[str]] = defaultdict(
-    lambda: ["setup.cfg", "tox.ini", "pyproject.toml", ".editorconfig"]
-)
-CONFIG_FILES["flake8"].extend([".flake8"])
-CONFIG_FILES["mypy"].extend(["mypy.ini", ".mypy.ini"])
-CONFIG_FILES["isort"].extend([".isort.cfg"])
-CONFIG_FILES["pytest"].extend(["pytest.ini"])
 
-
-def _parse_args(raw_args: Optional[List[str]]) -> Tuple[str, str, bool, List[str]]:
+def _parse_args(raw_args: Optional[List[str]]) -> Tuple[argparse.Namespace, List[str]]:
     """
     Parse command-line arguments.
 
@@ -48,6 +38,8 @@ def _parse_args(raw_args: Optional[List[str]]) -> Tuple[str, str, bool, List[str
         The notebooks or directories to run third-party tool on.
     allow_mutation
         Whether to allow 3rd party tools to modify notebooks.
+    nbqa_config
+        Config file for 3rd party tool (e.g. :code:`.mypy.ini`)
     kwargs
         Any additional flags passed to third-party tool (e.g. :code:`--quiet`).
 
@@ -69,9 +61,17 @@ def _parse_args(raw_args: Optional[List[str]]) -> Tuple[str, str, bool, List[str
         "root_dirs", nargs="+", help="Notebooks or directories to run command on."
     )
     parser.add_argument(
-        "--allow-mutation",
+        "--nbqa-mutate", action="store_true", help="Allows `nbqa` to modify notebooks.",
+    )
+    parser.add_argument(
+        "--nbqa-preserve-init",
         action="store_true",
-        help="Allows `nbqa` to modify notebooks.",
+        help="Use this if your 3rd party tool requires blank `__init__.py` files.",
+    )
+    parser.add_argument(
+        "--nbqa-config",
+        required=False,
+        help="Config file for third-party tool (e.g. `setup.cfg`)",
     )
     parser.add_argument("--version", action="version", version=f"nbQA {__version__}")
     try:
@@ -84,10 +84,7 @@ def _parse_args(raw_args: Optional[List[str]]) -> Tuple[str, str, bool, List[str
             )
             raise ValueError(msg) from exception
         sys.exit(0)  # pragma: nocover
-    command = args.command
-    root_dirs = args.root_dirs
-    allow_mutation = args.allow_mutation
-    return command, root_dirs, allow_mutation, kwargs
+    return args, kwargs
 
 
 def _get_notebooks(root_dir: str) -> Iterator[Path]:
@@ -346,17 +343,23 @@ def _replace_tmpdir_references(
     return new_out, new_err
 
 
-def _create_blank_init_files(notebook: Path, tmpdirname: str) -> None:
+def _create_blank_init_files(
+    nbqa_preserve_init: bool, notebook: Path, tmpdirname: str
+) -> None:
     """
     Replicate local (possibly blank) __init__ files to temporary directory.
 
     Parameters
     ----------
+    nbqa_preserve_init
+        Whether to copy __init__.py files to temp directory
     notebook
         Notebook third-party tool is being run against.
     tmpdirname
         Temporary directory to store converted notebooks in.
     """
+    if not nbqa_preserve_init:
+        return
     parts = notebook.resolve().relative_to(Path.cwd()).parts
     init_files = Path(parts[0]).rglob("__init__.py")
     for i in init_files:
@@ -364,27 +367,30 @@ def _create_blank_init_files(notebook: Path, tmpdirname: str) -> None:
         Path(tmpdirname).joinpath(i).touch()
 
 
-def _preserve_config_files(command: str, tmpdirname: str) -> None:
+def _preserve_config_files(nbqa_config: Optional[str], tmpdirname: str) -> None:
     """
-    Copy local config files to temporary directory.
+    Copy local config file to temporary directory.
 
     Parameters
     ----------
-    command
-        Third-party tool (e.g. mypy).
+    nbqa_config
+        Config file for third-party tool (e.g. mypy).
     tmpdirname
         Temporary directory to store converted notebooks in.
     """
-    config_files = (
-        i
-        for i in chain(*(Path.cwd().rglob(j) for j in CONFIG_FILES[command]))
-        if i.is_file()
+    if nbqa_config is None:
+        return
+    Path(tmpdirname).joinpath(
+        Path(nbqa_config).resolve().relative_to(Path.cwd())
+    ).parent.mkdir(parents=True, exist_ok=True)
+    shutil.copy(
+        str(nbqa_config),
+        str(
+            Path(tmpdirname).joinpath(
+                Path(nbqa_config).resolve().relative_to(Path.cwd())
+            )
+        ),
     )
-    for i in config_files:
-        Path(tmpdirname).joinpath(i.relative_to(Path.cwd())).parent.mkdir(
-            parents=True, exist_ok=True
-        )
-        shutil.copy(str(i), str(Path(tmpdirname).joinpath(i.relative_to(Path.cwd()))))
 
 
 def _ensure_cell_separators_remain(temp_python_file: Path) -> None:
@@ -535,20 +541,57 @@ def _run_command(
     return out, err, output_code, mutated
 
 
+def _get_configs(
+    args: argparse.Namespace, kwargs: List[str], tmpdirname: str,
+) -> Tuple[bool, bool]:
+    """
+    Deal with extra configs for 3rd party tool.
+
+    Parameters
+    ----------
+    args
+        Arguments passed to nbqa
+    kwargs
+        Extra flags for third party tool
+    tmpdirname
+        Temporary directory where notebooks are copied to.
+
+    Returns
+    -------
+    bool
+        Whether or not to copy __init__.py to temporary directory.
+    bool
+        Whether to allow nbqa to modify notebooks.
+    """
+    config = configparser.ConfigParser()
+    config.read(".nbqa.ini")
+    nbqa_config = args.nbqa_config
+    nbqa_preserve_init = args.nbqa_preserve_init
+    allow_mutation = args.nbqa_mutate
+    if args.command in config.sections():
+        addopts = config[args.command].get("addopts")
+        if addopts is not None:
+            kwargs.extend(config[args.command]["addopts"].split())
+        if nbqa_config is None:
+            nbqa_config = config[args.command].get("config")
+        if not nbqa_preserve_init:
+            nbqa_preserve_init = bool(config[args.command].get("preserve_init"))
+        if not allow_mutation:
+            allow_mutation = bool(config[args.command].get("mutate"))
+    _preserve_config_files(nbqa_config, tmpdirname)
+    return nbqa_preserve_init, allow_mutation
+
+
 def _run_on_one_root_dir(
-    root_dir: str, command: str, allow_mutation: bool, kwargs: List[str]
+    root_dir: str, args: argparse.Namespace, kwargs: List[str]
 ) -> int:
     """
     Run third-party tool on a single notebook or directory.
 
     Parameters
     ----------
-    root_dir
-        Notebook or directory to run 3rd-party tool on.
-    command
-        Third-party tool (e.g. :code:`mypy`)
-    allow_mutation
-        Whether to allow 3rd party tool to modify notebooks.
+    args
+        Arguments passed to nbqa.
     kwargs
         Additional flags to pass to 3rd party tool
 
@@ -566,18 +609,15 @@ def _run_on_one_root_dir(
             for notebook in notebooks
         }
 
+        nbqa_preserve_init, allow_mutation = _get_configs(args, kwargs, tmpdirname)
+
         for notebook, temp_python_file in nb_to_py_mapping.items():
             save_source.main(notebook, temp_python_file)
             replace_magics.main(temp_python_file)
-            _create_blank_init_files(notebook, tmpdirname)
-        _preserve_config_files(command, tmpdirname)
+            _create_blank_init_files(nbqa_preserve_init, notebook, tmpdirname)
 
-        config = configparser.ConfigParser(allow_no_value=True)
-        config.read(".nbqa.ini")
-        if command in config.sections():
-            kwargs.extend(config[command]["addopts"].split())
         out, err, output_code, mutated = _run_command(
-            command, root_dir, tmpdirname, nb_to_py_mapping, kwargs
+            args.command, root_dir, tmpdirname, nb_to_py_mapping, kwargs
         )
 
         out, err = _replace_tmpdir_references(out, err)
@@ -592,10 +632,10 @@ def _run_on_one_root_dir(
                         """\
                         💥 Mutation detected, will not reformat!
 
-                        To allow for mutation, please use the `--allow-mutation` flag, e.g.
+                        To allow for mutation, please use the `--nbqa-mutate` flag, e.g.
 
                         ```
-                        nbqa black my_notebook.ipynb --allow-mutation
+                        nbqa black my_notebook.ipynb --nbqa-mutate
                         ```
                         """
                     )
@@ -621,11 +661,9 @@ def main(raw_args: Optional[List[str]] = None) -> None:
         Command-line arguments (if calling this function directly), defaults to
         :code:`None` if calling via command-line.
     """
-    command, root_dirs, allow_mutation, kwargs = _parse_args(raw_args)
+    args, kwargs = _parse_args(raw_args)
 
-    output_codes = [
-        _run_on_one_root_dir(i, command, allow_mutation, kwargs) for i in root_dirs
-    ]
+    output_codes = [_run_on_one_root_dir(i, args, kwargs) for i in args.root_dirs]
 
     sys.exit(int(any(output_codes)))
 
